Plugins/VcsPlugins/vcsMercurial/HgBundleDialog.py

changeset 1274
442c748018c5
parent 1131
7781e396c903
child 1509
c0b5e693b0eb
diff -r 7b4d9f1d7c6c -r 442c748018c5 Plugins/VcsPlugins/vcsMercurial/HgBundleDialog.py
--- a/Plugins/VcsPlugins/vcsMercurial/HgBundleDialog.py	Sat Sep 03 17:13:31 2011 +0200
+++ b/Plugins/VcsPlugins/vcsMercurial/HgBundleDialog.py	Sun Sep 04 15:17:10 2011 +0200
@@ -45,8 +45,8 @@
         Private slot to update the OK button.
         """
         enabled = True
-        if self.idButton.isChecked():
-            enabled = self.idEdit.text() != ""
+        if self.multipleButton.isChecked():
+            enabled = self.multipleEdit.toPlainText() != ""
         elif self.tagButton.isChecked():
             enabled = self.tagCombo.currentText() != ""
         elif self.branchButton.isChecked():
@@ -57,9 +57,9 @@
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(enabled)
     
     @pyqtSlot(bool)
-    def on_idButton_toggled(self, checked):
+    def on_multipleButton_toggled(self, checked):
         """
         Private slot to handle changes of the ID select button.
         
         @param checked state of the button (boolean)
         """
@@ -92,12 +92,10 @@
         """
         self.__updateOK()
     
-    @pyqtSlot(str)
-    def on_idEdit_textChanged(self, txt):
+    @pyqtSlot()
+    def on_multipleEdit_textChanged(self):
         """
-        Private slot to handle changes of the ID edit.
-        
-        @param txt text of the edit (string)
+        Private slot to handle changes of the Multiple edit.
         """
         self.__updateOK()
     
@@ -132,20 +130,21 @@
         """
         Public method to retrieve the bundle data.
         
-        @return tuple naming the revision, the compression type and a flag indicating
-            to bundle all changesets (string, string, boolean)
+        @return tuple naming the revisions, base revisions, the compression type and
+            a flag indicating to bundle all changesets (string, string, boolean)
         """
-        if self.numberButton.isChecked():
-            rev = str(self.numberSpinBox.value())
-        elif self.idButton.isChecked():
-            rev = self.idEdit.text()
+        if self.multipleButton.isChecked():
+            revs = self.multipleEdit.toPlainText().strip().splitlines()
         elif self.tagButton.isChecked():
-            rev = self.tagCombo.currentText()
+            revs = [self.tagCombo.currentText()]
         elif self.branchButton.isChecked():
-            rev = self.branchCombo.currentText()
+            revs = [self.branchCombo.currentText()]
         elif self.bookmarkButton.isChecked():
-            rev = self.bookmarkCombo.currentText()
+            revs = [self.bookmarkCombo.currentText()]
         else:
-            rev = ""
+            revs = []
         
-        return rev, self.compressionCombo.currentText(), self.allCheckBox.isChecked()
+        baseRevs = self.baseRevisionsEdit.toPlainText().strip().splitlines()
+        
+        return (revs, baseRevs, self.compressionCombo.currentText(),
+            self.allCheckBox.isChecked())
@@ -57,9 +57,9 @@
         """
-        Private slot to handle changes of the ID select button.
+        Private slot to handle changes of the Multiple select button.
         
         @param checked state of the button (boolean)

eric ide

mercurial